SystemOrganization addCategory: #'Seaside-Tests-Development'!

WAContextTestCase subclass: #WADispatcherComponentTest
	instanceVariableNames: 'rootHanlder childHanlder configApplication normalApplication childApplication configComponent'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Development'!

!WADispatcherComponentTest methodsFor: 'private' stamp: 'jf 9/29/2008 09:54'!
handlersToPush
	^super handlersToPush, (Array
		with: configApplication
		with: WASession new)! !

!WADispatcherComponentTest methodsFor: 'running' stamp: 'MAD 9/13/2008 16:27'!
setUp
	super setUp.
	rootHanlder := WADispatcher named: 'seaside'.
	childHanlder := WADispatcher register: 'child' in: rootHanlder.
	
	configApplication := WAApplication register: 'config' in: rootHanlder.
	configApplication configuration addParent: WARenderLoopConfiguration instance.
	configApplication preferenceAt: #rootClass put: WADispatcherEditor.
	
	normalApplication := WAApplication register: 'counter' in: childHanlder.
	normalApplication configuration addParent: WARenderLoopConfiguration instance.
	normalApplication preferenceAt: #rootClass put: WADispatcherEditor! !

!WADispatcherComponentTest methodsFor: 'testing' stamp: 'jf 10/18/2008 12:37'!
testChildApplication
	| context |
	configComponent := WADispatcherEditor on: rootHanlder.
	
	context := self requestContextWithUrl: '/seaside/config/child/counter'.
	
	self
		should: [ configComponent initialRequest: context request ]
		raise: WARenderNotification.
	
	self assert: configComponent handler == childHanlder
	! !

!WADispatcherComponentTest methodsFor: 'testing' stamp: 'lr 9/13/2008 11:41'!
testNestedDispatcher
	| context |
	configComponent := WADispatcherEditor on: rootHanlder.
	context := self requestContextWithUrl: '/seaside/config/child'.
	
	configComponent initialRequest: context request.
	self assert: configComponent handler == childHanlder! !

TestCase subclass: #WACloneHandlerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Development'!

!WACloneHandlerTest methodsFor: 'as yet unclassified' stamp: 'jf 10/7/2008 01:22'!
testCloneApplication
	| app handler key clone |
	app := (WADispatcher named: 'root') register: (WAApplication named: 'app').
	handler := WARequestHandler new.
	key := app ensureKeyForHandler: handler.
	
	clone := app cloneHandler.
	
	self assert: key = (app ensureKeyForHandler: handler).
	self deny: key = (clone ensureKeyForHandler: handler).! !

TestCase subclass: #WADebugErrorHandlerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Development'!

!WADebugErrorHandlerTest commentStamp: 'jf 9/19/2008 19:32' prior: 0!
This isn't really a unit test of WADebugErrorHandler but rather a test that tries to replicate a simple version of the same error handling behaviour upon which the error handler depends. The error handler itself would be hard to test because it opens a debugger as its first action.

This should at least help confirm that the assumptions that were in place when writing the handler on Squeak hold true on other platforms.!

!WADebugErrorHandlerTest methodsFor: 'as yet unclassified' stamp: 'jf 9/19/2008 19:03'!
handleException: anException debuggerSimulation: debugBlock
	debugBlock ifCurtailed: [^  #aborted].
	anException resume! !

!WADebugErrorHandlerTest methodsFor: 'as yet unclassified' stamp: 'jf 9/19/2008 19:28'!
simulateWithDebugBlock: debugBlock progress: desiredProgress result: desiredResult
	"Set up a known working mechanism similar to the error handler so we can
	test whether the underlying system works the same way as on Squeak
	where WADebugErrorHandler was originally developed."
	
	| progress semaphore result |
	progress := OrderedCollection new.
	
	semaphore := SeasidePlatformSupport semaphoreClass new.
	
	[[ result := [
		progress add: #a.
		1/0.
		progress add: #b.
		#resumed ]
			on: Error
			do: [ :e |
				progress add: #c.
				self
					handleException: e
					debuggerSimulation: [
						progress add: #d.
						debugBlock value.
						progress add: #e ] ]
	] ensure: [ semaphore signal ] ] fork.

	semaphore wait.
	
	self assert: progress asArray = desiredProgress asArray.
	self assert: result = desiredResult.! !

!WADebugErrorHandlerTest methodsFor: 'as yet unclassified' stamp: 'jf 9/19/2008 19:25'!
testMechanismAbort
	"Test if things behave as expected when simulating a Debugger being closed
	(in other words, the process being terminated)."
	
	self
		simulateWithDebugBlock: [Processor activeProcess terminate]
		progress: #(a c d)
		result: #aborted! !

!WADebugErrorHandlerTest methodsFor: 'as yet unclassified' stamp: 'jf 9/19/2008 19:29'!
testMechanismProceed
	"Test if things behave as expected when simulating a Debugger being proceeded
	(in other words, the process being terminated)."
	
	self
		simulateWithDebugBlock: [nil]
		progress: #(a c d e b)
		result: #resumed! !

TestCase subclass: #WADevelopmentFilesTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Development'!

!WADevelopmentFilesTest methodsFor: 'testing' stamp: 'obi 10/12/2008 19:38'!
testDevelopmentFilenames
	| expected actual |
	expected := #(#configPng #codebrowserPng #haloCss #inspectorPng #memoryPng #profilerPng #styleeditorPng #toolbarCss #toolsCss).
	actual := WADevelopmentFiles new fileSelectors.
	"VW does not implement #= in Sets"
	self assert: actual size = expected size.
	expected do: [ :each |
		self assert: (expected includes: each)]! !
